@@ -13,15 +13,17 @@ checkcolnames<-function(data, tab, soilcarbon_template){
   cat("\t",tab,"tab...")
   data_colnames<-colnames(data[[tab]])
   template_colnames<-colnames(soilcarbon_template[[tab]])
-
+  error=0
   notintemplate<-setdiff(data_colnames, template_colnames)
   if (length(notintemplate>0)) {
     message("\nWARNING...column names in the '",tab,"' tab do not match template, see below:")
     cat("\t\t columns found in '", tab, "' tab of dataset but not in template\n" )
+    error<-error+1
     for (i in 1:length(notintemplate)){
       cat("\t\t", i, ". ", notintemplate[i] ,"\n")
     }
 
     } else cat("OK\n")
+  return(error)
 
 }
